@@ -13,10 +13,9 @@ use Carp();
 use Scalar::Util();
 use Rose::HTML::Util();
 
-use Rose::HTML::Form::Field;
-our @ISA = qw(Rose::HTML::Form::Field);
+use base 'Rose::HTML::Form::Field';
 
-our $VERSION = '0.554';
+our $VERSION = '0.606';
 
 our $Debug = undef;
 
@@ -370,7 +369,7 @@ sub _args_to_items
                                 $label_method => $labels{$value}));
     }
   }
-$DB::single = 1;
+
   foreach my $item (@$items)
   {
     # Connect item to group
