@@ -7,10 +7,9 @@ use Rose::HTML::Form::Field::Time::Minutes;
 use Rose::HTML::Form::Field::Time::Seconds;
 use Rose::HTML::Form::Field::PopUpMenu;
 
-use Rose::HTML::Form::Field::Time::Split;
-our @ISA = qw(Rose::HTML::Form::Field::Time::Split);
+use base 'Rose::HTML::Form::Field::Time::Split';
 
-our $VERSION = '0.550';
+our $VERSION = '0.606';
 
 sub build_field
 {
@@ -179,4 +178,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
